# ieltspeak

[![PyPI - Version](https://img.shields.io/pypi/v/ieltspeak.svg)](https://pypi.org/project/ieltspeak)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ieltspeak.svg)](https://pypi.org/project/ieltspeak)

-----

## Table of Contents

- [ieltspeak](#ieltspeak)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
  - [Usage](#usage)
  - [License](#license)

## Installation

```console
pip install ieltspeak
```

## Usage

```
ieltspeak get-topic --category event --part 1
ieltspeak get-topic --category location --part 2and3
```

## License

`ieltspeak` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
